;**************************************************************************
;* FileName	: NLCDTEST.ASM
;* Date 	: 03.02.2003
;* File version : v1.00
;*
;* Author	: MIKO, Imre
;* Company	:
;* Homepage	: http://majki.fw.hu
;* E-mail	: majki@fw.hu
;*
;*-------------------------------------------------------------------------
;*
;* Description	: Numeric LCD test.
;*		  ==================================
;*		  Test code for LTSCC7021A LCD Module. (with NEC D7225)
;*
;*
;*-------------------------------------------------------------------------
;*
;* Connections	:	       _______	 _______
;*			      |       \_/	|
;*		       n.c. ==| RA2	    RA1 |== n.c.
;*		       n.c. ==| RA3	    RA0 |== n.c.
;*		       n.c. ==| RA4	   OSC1 |== quartz1
;*		     -reset ==|-MCLR	   OSC2 |== quartz2
;*			GND ==| Vss	    Vdd |== +5V
;*		   NLCD_CS0 ==| RB0	    RB7 |== n.c.
;*		   NLCD_CS1 ==| RB1	    RB6 |== n.c.
;*		   NLCD_CLK ==| RB2	    RB5 |== n.c.
;*		   NLCD_SI  ==| RB3	    RB4 |== NLCD_RESET
;*			      |_________________|
;*				   PIC16F84 
;*
;*-------------------------------------------------------------------------
;*
;* Resource	: Ports 	  :    xx /   13 pin   (   %)
;*		  Data memory	  :    xx /   68 byte  (   %)
;*		  Prog memory	  :   xxx / 1024 word  (   %)
;*		  Timer0	  : 
;*		  Interrupt	  : 
;*
;**************************************************************************
;* Revision History:
;*
;* 1.00	  21/08/2000 	Initial Release
;*
;**************************************************************************

	list	p=16f84, r=dec, l=0

;***** INCLUDES ***********************************************************

	include "p16f84.inc"
	include "..\..\modules\base.inc"

;***** CONFIG ************************************************************

	__CONFIG _XT_OSC & _WDT_OFF & _PWRTE_ON & _CP_OFF
	__IDLOCS 0100h			; version

	EXPAND_MACROS	EXP_COND	; macro expansion mode

;***** DEFINES ************************************************************
;#define DEBUG				; for some debug message
;#define NO_DELAY			; for fast simulation
;#define NO_RS232			; for fast simulation


xtal_freq	EQU	4 MHz	  	; crystal frequency
core_freq	EQU	xtal_freq/4	; core operating frequency

#define		NLCD_ALPHA

; ----- porta -------------------------------------------------------------

#define		PORTA_0		PORTA,0		; free
#define		PORTA_1		PORTA,1		; free
#define		PORTA_2		PORTA,2		; free
#define		PORTA_3		PORTA,3		; free
#define		PORTA_4		PORTA,4		; free (open drain!)

; ----- portb -------------------------------------------------------------

#define		NLCD_CS0	PORTB,0		; out
#define		NLCD_CS1	PORTB,1		; out
#define		NLCD_CLK	PORTB,2		; out
#define		NLCD_SI		PORTB,3		; out
#define		NLCD_RESET	PORTB,4		; out
#define		PORTB_5		PORTB,5		; free
#define		PORTB_6		PORTB,6		; free
#define		PORTB_7		PORTB,7		; free



;***** MACROS *************************************************************

	include "..\..\modules\wait.mac"
	include	"..\..\modules\nlcd.mac"

	


;***** CONSTANT DEFINITIONS ***********************************************

option_val	EQU	00000010b	; Timer source : intclk / 8
trisa_val	EQU	00011111b	; TRISA value (all input)
trisb_val	EQU	11111111b	; TRISB value (all input)
intcon_val	EQU	00100000b	; Interrupt control




;***** VARIABLE DEFINITIONS ***********************************************
	cblock	0Ch
		w_temp			; variable used for context saving
		status_temp		; variable used for context saving
		fsr_temp		; variable used for context saving



;--------------------------------------------------------------------------



	endc




;***** ENTRY POINT ********************************************************
		ORG	000h		; processor reset vector

		clrwdt
		clrf	PORTA		; clear latch
		clrf	PORTB		; clear latch
		goto	start


;***** IT HANDLER *********************************************************
;* Interrupt handler
;* <comment>
;**************************************************************************
		ORG	004h		; interrupt vector location
		movwf	w_temp		; save off current W register contents
		swapf	STATUS,w	; move STATUS register into W register
		movwf	status_temp	; save off contents of STATUS register

		movf	FSR,w		; save FSR
		movwf	fsr_temp
;--------------------------------------------------------------------------

		; <IT Code>

;--------------------------------------------------------------------------
		movf	fsr_temp,w	; restore FSR
		movwf	FSR

		swapf	status_temp,w	; retrieve copy of STATUS register
		movwf	STATUS		; restore pre-isr STATUS register contents
		swapf	w_temp,f
		swapf	w_temp,w	; restore pre-isr W register contents
		retfie			; return from interrupt




;***** REAL PROGRAM START *************************************************
start
;----- set configuration --------------------------------------------------
		bank1
		ERRORLEVEL -302
		movlw	option_val
		movwf	OPTION_REG	; set OPTION_REG
		movlw	trisa_val
		movwf	TRISA		; set TRISA
		movlw	trisb_val
		movwf	TRISB		; set TRISB

		bank0
		ERRORLEVEL +302
		movlw	intcon_val	
		movwf	INTCON		; set INTCON

;----- inits --------------------------------------------------------------


		NLCD_INIT



;--------------------------------------------------------------------------

		movlw	'0'
		NLCD_PRINTC			

		NLCD_GOTOX 10

		movlw	'0'
		NLCD_PRINTC	
		
		WAIT	1 Seconds, 0
;--------------------------------------------------------------------------

		NLCD_DISPLAYOFF
		WAIT	1 Seconds, 0
;--------------------------------------------------------------------------

		NLCD_DISPLAYON
		NLCD_SYMBOL NLCDS_SPEAKER | NLCDS_PHONE
		WAIT	1 Seconds, 0
;--------------------------------------------------------------------------

		NLCD_CLEAR
		NLCD_PRINTCS "0123456789012345678"		
		WAIT	1 Seconds, 0
;--------------------------------------------------------------------------

		NLCD_GOTOX 0
		NLCD_PRINTCS "HELLO"
		NLCD_CLEARREST




;----- main cycle  --------------------------------------------------------


main_loop	goto	main_loop





;***** SUB1 ***************************************************************
;* 
;* Input :              		; 
;* Output:  				; 
;* Clock :   
;**************************************************************************

sub1 


		return

;**************************************************************************

	include	"..\..\modules\nlcd.inc"
	include "..\..\modules\wait.inc"


	end				  ; end of program








